@@ -422,12 +422,15 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
  * Overwrite to initialize combo boxes and other UI elements of the options tool
  * bar.
  */
-EAction.prototype.initUiOptions = function(resume, optionsToolBar) {
+EAction.prototype.initUiOptions = function(resume, optionsToolBar, forDialog) {
     if (isNull(optionsToolBar)) {
         return;
     }
+    if (isNull(forDialog)) {
+        forDialog = false;
+    }
 
-    OptionsToolBar.initShortcuts(optionsToolBar);
+    OptionsToolBar.initShortcuts(optionsToolBar, forDialog);
 };
 
 /**
@@ -599,7 +602,7 @@ EAction.prototype.showDialog = function() {
     }
 
     this.dialog = WidgetFactory.createDialog(this.includeBasePath, this.dialogUiFile, EAction.getMainWindow());
-    this.initUiOptions(false, this.dialog);
+    this.initUiOptions(false, this.dialog, true);
     WidgetFactory.restoreState(this.dialog, this.settingsGroup, this);
     var title = this.getToolTitle();
     if (title.indexOf("\t")!==-1) {
@@ -651,7 +654,7 @@ EAction.prototype.showDialog = function() {
         noSyncWidgets[i].setProperty("Loaded", false);
     }
 
-    destr(this.dialog);
+    destrDialog(this.dialog);
     this.dialog = undefined;
 
 //    var view = EAction.getGraphicsView();
@@ -1640,8 +1643,9 @@ EAction.getScales = function(unit) {
 };
 
 /**
- * Called by updatePreview. Implementations must return an ROperation subclass
- * object for the operation that should be previewed.
+ * Called by updatePreview and applyOperation.
+ * Implementations must return an ROperation subclass
+ * object for the operation that should be previewed or applied.
  */
 EAction.prototype.getOperation = function(preview) {
     return undefined;
@@ -1998,6 +2002,14 @@ EAction.prototype.getToolTitle = function() {
     return guiAction.text.replace("&", "");
 };
 
+EAction.prototype.getClassName = function() {
+    var guiAction = this.getGuiAction();
+    if (isNull(guiAction)) {
+        return "";
+    }
+    return guiAction.getScriptClass();
+};
+
 EAction.disableCoordinateWidget = function() {
     EAction.enableCoordinateWidget(false);
 };
@@ -2023,7 +2035,7 @@ EAction.enableCoordinateWidget = function(enable) {
 
 /**
  * \return ID of entity closest to the mouse cursor. No handling of ambiguous results.
- * \param event RRInputEvent
+ * \param event RInputEvent
  * \param range Cursor range in pixels
  */
 EAction.getEntityIdUnderCursor = function(di, event, range, selectable) {
@@ -2047,7 +2059,7 @@ EAction.getEntityIdUnderCursor = function(di, event, range, selectable) {
 
 /**
  * \return Array of entity IDs of entities closest to the mouse cursor.
- * \param event RRInputEvent
+ * \param event RInputEvent
  * \param range Cursor range in pixels
  */
 EAction.getEntityIdsUnderCursor = function(di, event, range, selectable) {
