@@ -104,6 +104,7 @@ Explode.explodeSelection = function(di, toolTitle) {
         //var newShapes = [];
         //var newEntities = [];
 
+        // list of new entities and shapes:
         var news = Explode.explodeEntity(entity, options);
 
         if (isNull(news)) {
@@ -122,7 +123,6 @@ Explode.explodeSelection = function(di, toolTitle) {
                     op.addObject(newEntity, false, true);
 
                     if (isBlockReferenceEntity(newEntity)) {
-                        qDebug("old block ref id: ", newEntity.getId());
                         blockReferenceMap[newEntity.getId()] = newEntity;
                     }
                     else if (isAttributeEntity(newEntity)) {
@@ -168,22 +168,24 @@ Explode.explodeSelection = function(di, toolTitle) {
         for (i=0; i<attributeEntities.length; i++) {
             var attributeEntity = attributeEntities[i].clone();
 
-            if (RSettings.getQtVersion()>=0x060000) {
-                var newAttributeId = t.getNewObjectId(attributeEntity.getId());
-                storage.setObjectId(attributeEntity, newAttributeId);
-            }
+            // 20250102: not needed anymore, since using QSharedPointer:
+            // if (RSettings.getQtVersion()>=0x060000) {
+            //     var newAttributeId = t.getNewObjectId(attributeEntity.getId());
+            //     storage.setObjectId(attributeEntity, newAttributeId);
+            // }
 
             // find parent entity of attribute:
             var blockReferenceEntity = blockReferenceMap[attributeEntity.getParentId()];
             if (!isNull(blockReferenceEntity)) {
                 // update parent ID:
-                if (RSettings.getQtVersion()>=0x060000) {
-                    var newAttributeParentId = t.getNewObjectId(blockReferenceEntity.getId());
-                    storage.setEntityParentId(attributeEntity, newAttributeParentId);
-                }
-                else {
-                    storage.setEntityParentId(attributeEntity, blockReferenceEntity.getId());
-                }
+                // 20250102: not needed anymore, since using QSharedPointer:
+                // if (RSettings.getQtVersion()>=0x060000) {
+                //     var newAttributeParentId = t.getNewObjectId(blockReferenceEntity.getId());
+                //     storage.setEntityParentId(attributeEntity, newAttributeParentId);
+                // }
+                // else {
+                    storage.setEntityParentId(getPtr(attributeEntity), blockReferenceEntity.getId());
+                // }
                 op.addObject(attributeEntity, false);
             }
         }
@@ -346,6 +348,17 @@ Explode.explodeEntity = function(entity, options) {
                     prevLeftPl = leftPl;
                     prevRightPl = rightPl;
                 }
+
+                else if (leftPl.countSegments()===1) {
+                    // add only left segment:
+                    ret.push(leftPl);
+                }
+
+                else if (rightPl.countSegments()===1) {
+                    // add only right segment:
+                    ret.push(rightPl);
+                }
+
                 //else if (leftPl.countSegments()>1 || rightPl.countSegments()>1) {
                 else if (!leftPl.isEmpty()) {
                     //ret.push(pls[k]);
@@ -372,6 +385,20 @@ Explode.explodeEntity = function(entity, options) {
             if (!isNull(lastSegment)) {
                 ret.push(lastSegment);
             }
+
+            // special case of donut shape with hole diameter=0 which explodes to circle:
+            if (ret.length===2) {
+                if (isPolylineShape(ret[0]) && isPolylineShape(ret[1]) &&
+                    ret[0].countSegments()===1 && ret[1].countSegments()===1 &&
+                    ret[0].getStartPoint().equalsFuzzy(ret[1].getEndPoint()) &&
+                    ret[0].getEndPoint().equalsFuzzy(ret[1].getStartPoint()) &&
+                    RMath.fuzzyCompare(ret[0].getBulgeAt(0), 1.0) &&
+                    RMath.fuzzyCompare(ret[1].getBulgeAt(0), 1.0)) {
+
+                    var seg = ret[0].getSegmentAt(0);
+                    ret = [ new RCircle(seg.getCenter(), seg.getRadius()) ];
+                }
+            }
         }
         else {
             var polySegments = polyline.getExploded();
@@ -426,7 +453,8 @@ Explode.explodeEntity = function(entity, options) {
                     var pl = new RPolyline();
                     for (n=0; n<shapes.length; n++) {
                         shape = shapes[n];
-                        pl.appendShape(shape.clone());
+                        var shapeClone = shape.clone()
+                        pl.appendShape(getPtr(shapeClone));
                         //ret.push(shape.clone());
                     }
                     ret.push(pl);
@@ -453,7 +481,7 @@ Explode.explodeEntity = function(entity, options) {
         shapes = entity.getShapes();
         for (k=0; k<shapes.length; k++) {
             if (shapes[k].isValid()) {
-                ret.push(getPtr(shapes[k]));
+                ret.push(shapes[k]);
             }
         }
         var textData = entity.getData().getTextData();
@@ -591,7 +619,7 @@ Explode.explodeEntity = function(entity, options) {
                         if (textToPolylines) {
                             // explode to polylines:
                             if (!isNull(plText) && plText.getEndPoint().equalsFuzzy(shape.getStartPoint())) {
-                                plText.appendShape(sc);
+                                plText.appendShape(getPtr(sc));
                             }
                             else {
                                 if (!isNull(plText)) {
@@ -600,7 +628,7 @@ Explode.explodeEntity = function(entity, options) {
 
                                 plText = new RPolyline();
                                 ret.push(plText);
-                                plText.appendShape(sc);
+                                plText.appendShape(getPtr(sc));
                             }
                         }
                         else {
@@ -627,12 +655,7 @@ Explode.explodeEntity = function(entity, options) {
         d.setParentId(RObject.INVALID_ID);
         e = new RTextEntity(document, d);
         e.setSelected(true);
-        if (isFunction(entity.data)) {
-            e.copyAttributesFrom(getPtr(entity));
-        }
-        else {
-            e.copyAttributesFrom(entity);
-        }
+        e.copyAttributesFrom(getPtr(entity));
         ret.push(e);
     }
 
@@ -652,7 +675,7 @@ Explode.explodeEntity = function(entity, options) {
                     e.setRowCount(1);
                     e.setColumnCount(1);
                     e.setPosition(pos.operator_add(offset));
-                    storage.setObjectId(e, RObject.INVALID_ID);
+                    storage.setObjectId(getPtr(e), RObject.INVALID_ID);
                     e.setSelected(true);
                     ret.push(e);
                 }
@@ -709,12 +732,7 @@ Explode.explodeEntity = function(entity, options) {
                         else {
                             // hatch pattern: add transformed entity:
                             e.setSelected(true);
-                            if (isFunction(subEntity.data)) {
-                                e.copyAttributesFrom(getPtr(subEntity));
-                            }
-                            else {
-                                e.copyAttributesFrom(subEntity);
-                            }
+                            e.copyAttributesFrom(getPtr(subEntity));
                             ret.push(e);
                         }
                     }
@@ -723,12 +741,7 @@ Explode.explodeEntity = function(entity, options) {
                         // solid hatch: add new solid hatch:
                         e = new RHatchEntity(document, explodedHatchData);
                         e.setSelected(true);
-                        if (isFunction(subEntity.data)) {
-                            e.copyAttributesFrom(getPtr(subEntity));
-                        }
-                        else {
-                            e.copyAttributesFrom(subEntity);
-                        }
+                        e.copyAttributesFrom(getPtr(subEntity));
                         ret.push(e);
                     }
                     continue;
