@@ -250,7 +250,7 @@ Stretch.getStrechOperation = function(document, polygon, preview, offset, layerI
 
         // check if the entity intersects with any of the polygon edges:
         var gotIntersection = false;
-        if (entity.intersectsWith(polygon)) {
+        if (entity.intersectsWith(getPtr(polygon))) {
             gotIntersection = true;
         }
 
@@ -312,7 +312,13 @@ Stretch.prototype.getAuxPreview = function() {
         ret.push(line);
 
         if (!isNull(offset)) {
-            line = line.copy();
+            if (RSettings.getQtVersion()>=0x060000) {
+                line = line.clone();
+            }
+            else {
+                line = line.copy();
+            }
+
             line.move(offset);
             ret.push(line);
         }
